@@ -178,12 +178,12 @@ TEST(UtilityTest, ConvertMsgsPlaneToMath)
 /////////////////////////////////////////////////
 TEST(MsgsTest, ConvertMathInertialToMsgs)
 {
-  const auto pose = math::Pose3d(5, 6, 7, 0.4, 0.5, 0.6);
+  const auto pose = ignition::math::Pose3d(5, 6, 7, 0.4, 0.5, 0.6);
   msgs::Inertial msg = msgs::Convert(
-      math::Inertiald(
-        math::MassMatrix3d(12.0,
-          math::Vector3d(2, 3, 4),
-          math::Vector3d(0.1, 0.2, 0.3)),
+      ignition::math::Inertiald(
+        ignition::math::MassMatrix3d(12.0,
+          ignition::math::Vector3d(2, 3, 4),
+          ignition::math::Vector3d(0.1, 0.2, 0.3)),
         pose));
 
   EXPECT_DOUBLE_EQ(12.0, msg.mass());
@@ -199,12 +199,12 @@ TEST(MsgsTest, ConvertMathInertialToMsgs)
 /////////////////////////////////////////////////
 TEST(MsgsTest, ConvertMsgsInertialToMath)
 {
-  const auto pose = math::Pose3d(5, 6, 7, 0.4, 0.5, 0.6);
+  const auto pose = ignition::math::Pose3d(5, 6, 7, 0.4, 0.5, 0.6);
   msgs::Inertial msg = msgs::Convert(
-      math::Inertiald(
-        math::MassMatrix3d(12.0,
-          math::Vector3d(2, 3, 4),
-          math::Vector3d(0.1, 0.2, 0.3)),
+      ignition::math::Inertiald(
+        ignition::math::MassMatrix3d(12.0,
+          ignition::math::Vector3d(2, 3, 4),
+          ignition::math::Vector3d(0.1, 0.2, 0.3)),
         pose));
   auto inertial = msgs::Convert(msg);
 
@@ -222,9 +222,9 @@ TEST(MsgsTest, ConvertMsgsInertialToMath)
 TEST(MsgsTest, ConvertMathMassMatrix3ToMsgs)
 {
   msgs::Inertial msg = msgs::Convert(
-      math::MassMatrix3d(12.0,
-        math::Vector3d(2, 3, 4),
-        math::Vector3d(0.1, 0.2, 0.3)));
+      ignition::math::MassMatrix3d(12.0,
+        ignition::math::Vector3d(2, 3, 4),
+        ignition::math::Vector3d(0.1, 0.2, 0.3)));
 
   EXPECT_DOUBLE_EQ(12.0, msg.mass());
   EXPECT_DOUBLE_EQ(2.0, msg.ixx());
@@ -233,7 +233,7 @@ TEST(MsgsTest, ConvertMathMassMatrix3ToMsgs)
   EXPECT_DOUBLE_EQ(0.1, msg.ixy());
   EXPECT_DOUBLE_EQ(0.2, msg.ixz());
   EXPECT_DOUBLE_EQ(0.3, msg.iyz());
-  EXPECT_EQ(math::Pose3d::Zero, msgs::Convert(msg.pose()));
+  EXPECT_EQ(ignition::math::Pose3d::Zero, msgs::Convert(msg.pose()));
 }
 
 /////////////////////////////////////////////////
@@ -316,131 +316,22 @@ TEST(UtilityTest, ConvertFloat)
   EXPECT_DOUBLE_EQ(s, 0.999f);
 }
 
-
 /////////////////////////////////////////////////
-TEST(UtilityTest, ConvertFuelMetadata)
+TEST(UtilityTest, ConvertTimePoint)
 {
-  msgs::FuelMetadata metaMsg;
-  std::string modelConfigInput, worldConfigInput;
+  std::chrono::steady_clock::duration timePoint =
+    std::chrono::steady_clock::duration::zero();
+  msgs::Time msg = msgs::Convert(timePoint);
+  EXPECT_EQ(0, msg.sec());
+  EXPECT_EQ(0, msg.nsec());
 
-  // test ConvertFuelMetadata(string, msgs::FuelMetadata)
-  {
-    EXPECT_FALSE(msgs::ConvertFuelMetadata(modelConfigInput, metaMsg));
+  std::chrono::steady_clock::duration s = msgs::Convert(msg);
+  EXPECT_EQ(s, std::chrono::steady_clock::duration::zero());
 
-    metaMsg.Clear();
-    modelConfigInput = "<test/>";
-    EXPECT_FALSE(msgs::ConvertFuelMetadata(modelConfigInput, metaMsg));
-
-    metaMsg.Clear();
-    modelConfigInput = "<model>test</model>";
-    EXPECT_FALSE(msgs::ConvertFuelMetadata(modelConfigInput, metaMsg));
-
-    // Test <model>
-    metaMsg.Clear();
-    modelConfigInput = R"(
-      <model>
-        <name>test_model</name>
-      </model>
-    )";
-    EXPECT_FALSE(msgs::ConvertFuelMetadata(modelConfigInput, metaMsg));
-
-    metaMsg.Clear();
-    modelConfigInput = R"(<?xml version='1.0'?>
-  <model>
-    <sdf version='1.7'>model.sdf</sdf>
-    <name>test_model</name>
-    <version>3</version>
-    <description>A model for testing</description>
-    <author>
-      <name>Foo Bar</name>
-      <email>foo@bar.org</email>
-    </author>
-    <depend>
-      <model>
-        <uri>model://some_model</uri>
-      </model>
-    </depend>
-  </model>
-)";
-
-    EXPECT_TRUE(msgs::ConvertFuelMetadata(modelConfigInput, metaMsg));
-    EXPECT_EQ("test_model", metaMsg.name());
-    EXPECT_EQ(3, metaMsg.version());
-    EXPECT_EQ("A model for testing", metaMsg.description());
-    EXPECT_EQ("model.sdf", metaMsg.model().file());
-    EXPECT_EQ("sdf", metaMsg.model().file_format().name());
-    EXPECT_EQ(1, metaMsg.model().file_format().version().major());
-    EXPECT_EQ(7, metaMsg.model().file_format().version().minor());
-    EXPECT_EQ(1, metaMsg.authors().size());
-    EXPECT_EQ("Foo Bar", metaMsg.authors(0).name());
-    EXPECT_EQ("foo@bar.org", metaMsg.authors(0).email());
-    EXPECT_EQ(1, metaMsg.dependencies().size());
-    EXPECT_EQ("model://some_model", metaMsg.dependencies(0).uri());
-
-    // Test <world>
-    metaMsg.Clear();
-    worldConfigInput = R"(<?xml version='1.0'?>
-  <world>
-    <sdf version='1.7'>world.sdf</sdf>
-    <name>test_world</name>
-    <version>2</version>
-    <description>A world for testing</description>
-  </world>
-)";
-    EXPECT_TRUE(msgs::ConvertFuelMetadata(worldConfigInput, metaMsg));
-    EXPECT_EQ("test_world", metaMsg.name());
-    EXPECT_EQ(2, metaMsg.version());
-    EXPECT_EQ("A world for testing", metaMsg.description());
-    EXPECT_EQ("world.sdf", metaMsg.world().file());
-    EXPECT_EQ("sdf", metaMsg.world().file_format().name());
-    EXPECT_EQ(1, metaMsg.world().file_format().version().major());
-    EXPECT_EQ(7, metaMsg.world().file_format().version().minor());
-    EXPECT_EQ(0, metaMsg.authors().size());
-    EXPECT_EQ(0, metaMsg.dependencies().size());
-  }
-
-  // test ConvertFuelMetadata(msgs::FuelMetadata, string)
-  {
-    std::string modelConfig;
-
-    // Test <world>
-    metaMsg.Clear();
-    metaMsg.mutable_world()->set_file("world.sdf");
-    EXPECT_FALSE(msgs::ConvertFuelMetadata(metaMsg, modelConfig));
-
-    metaMsg.set_name("test_world");
-    metaMsg.set_description("A world for testing");
-    metaMsg.set_version(2);
-    metaMsg.mutable_world()->mutable_file_format()->set_name("sdf");
-    metaMsg.mutable_world()->mutable_file_format()
-           ->mutable_version()->set_major(1);
-    metaMsg.mutable_world()->mutable_file_format()
-           ->mutable_version()->set_minor(7);
-    EXPECT_TRUE(msgs::ConvertFuelMetadata(metaMsg, modelConfig));
-
-    EXPECT_EQ(worldConfigInput, modelConfig);
-
-    // Test <model>
-    metaMsg.Clear();
-    metaMsg.mutable_model()->set_file("model.sdf");
-    EXPECT_FALSE(msgs::ConvertFuelMetadata(metaMsg, modelConfig));
-
-    metaMsg.set_name("test_model");
-    metaMsg.set_description("A model for testing");
-    metaMsg.set_version(3);
-    metaMsg.mutable_model()->mutable_file_format()->set_name("sdf");
-    metaMsg.mutable_model()->mutable_file_format()
-           ->mutable_version()->set_major(1);
-    metaMsg.mutable_model()->mutable_file_format()
-           ->mutable_version()->set_minor(7);
-    EXPECT_TRUE(msgs::ConvertFuelMetadata(metaMsg, modelConfig));
-
-    metaMsg.add_authors()->set_name("Foo Bar");
-    metaMsg.mutable_authors(0)->set_email("foo@bar.org");
-    metaMsg.add_dependencies()->set_uri("model://some_model");
-    EXPECT_TRUE(msgs::ConvertFuelMetadata(metaMsg, modelConfig));
-    EXPECT_EQ(modelConfigInput, modelConfig);
-  }
+  timePoint = std::chrono::seconds(200) + std::chrono::nanoseconds(999);
+  msg = msgs::Convert(timePoint);
+  EXPECT_EQ(200, msg.sec());
+  EXPECT_EQ(999, msg.nsec());
 }
 
 /////////////////////////////////////////////////
@@ -522,13 +413,13 @@ TEST(UtilityTest, SetPlane)
 /////////////////////////////////////////////////
 TEST(MsgsTest, SetInertial)
 {
-  const auto pose = math::Pose3d(5, 6, 7, 0.4, 0.5, 0.6);
+  const auto pose = ignition::math::Pose3d(5, 6, 7, 0.4, 0.5, 0.6);
   msgs::Inertial msg;
-  msgs::Set(&msg, math::Inertiald(
-      math::MassMatrix3d(
+  msgs::Set(&msg, ignition::math::Inertiald(
+      ignition::math::MassMatrix3d(
         12.0,
-        math::Vector3d(2, 3, 4),
-        math::Vector3d(0.1, 0.2, 0.3)),
+        ignition::math::Vector3d(2, 3, 4),
+        ignition::math::Vector3d(0.1, 0.2, 0.3)),
       pose));
 
   EXPECT_DOUBLE_EQ(12.0, msg.mass());
@@ -545,10 +436,10 @@ TEST(MsgsTest, SetInertial)
 TEST(MsgsTest, SetMassMatrix3)
 {
   msgs::Inertial msg;
-  msgs::Set(&msg, math::MassMatrix3d(
+  msgs::Set(&msg, ignition::math::MassMatrix3d(
         12.0,
-        math::Vector3d(2, 3, 4),
-        math::Vector3d(0.1, 0.2, 0.3)));
+        ignition::math::Vector3d(2, 3, 4),
+        ignition::math::Vector3d(0.1, 0.2, 0.3)));
 
   EXPECT_DOUBLE_EQ(12.0, msg.mass());
   EXPECT_DOUBLE_EQ(2.0, msg.ixx());
@@ -557,7 +448,7 @@ TEST(MsgsTest, SetMassMatrix3)
   EXPECT_DOUBLE_EQ(0.1, msg.ixy());
   EXPECT_DOUBLE_EQ(0.2, msg.ixz());
   EXPECT_DOUBLE_EQ(0.3, msg.iyz());
-  EXPECT_EQ(math::Pose3d::Zero, msgs::Convert(msg.pose()));
+  EXPECT_EQ(ignition::math::Pose3d::Zero, msgs::Convert(msg.pose()));
 }
 
 /////////////////////////////////////////////////
@@ -686,7 +577,9 @@ TEST(MsgsTest, ConvertMsgsGeometryTypeToString)
 {
   CompareMsgsGeometryTypeToString(msgs::Geometry::BOX);
   CompareMsgsGeometryTypeToString(msgs::Geometry::SPHERE);
+  CompareMsgsGeometryTypeToString(msgs::Geometry::CAPSULE);
   CompareMsgsGeometryTypeToString(msgs::Geometry::CYLINDER);
+  CompareMsgsGeometryTypeToString(msgs::Geometry::ELLIPSOID);
   CompareMsgsGeometryTypeToString(msgs::Geometry::PLANE);
   CompareMsgsGeometryTypeToString(msgs::Geometry::IMAGE);
   CompareMsgsGeometryTypeToString(msgs::Geometry::HEIGHTMAP);
